@@ -15,7 +15,7 @@ Readonly::Array our @ABSOLUTE_LENGTHS => qw(cm mm in px pt pc);
 Readonly::Array our @RELATIVE_LENGTHS => qw(em ex ch rem vw vh vmin vmax %);
 Readonly::Array our @COLOR_FUNC => qw(rgb rgba hsl hsla);
 
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 sub check_array_css_color {
 	my ($self, $key) = @_;
@@ -67,7 +67,7 @@ sub check_css_unit {
 	_check_key($self, $key) && return;
 
 	my $value = $self->{$key};
-	my ($num, $unit) = $value =~ m/^(\d+)([^\d]*)$/ms;
+	my ($num, $unit) = $value =~ m/^(\d*\.?\d+)([^\d]*)$/ms;
 	if (! $num) {
 		err "Parameter '$key' doesn't contain number.",
 			'Value', $value,
@@ -576,6 +576,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
